==> nextcloud-14.0.13.zip: nextcloud/apps/serverinfo/l10n/ca.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informació del processador no disponible",
    "Load average" : "Càrrega mitja",
    "Last minute" : "Darrer minut",
    "Memory info not available" : "Informació de la memòria no disponible",
    "Total" : "Total",
    "Current usage" : "Ús actual",
    "Users" : "Usuaris",
    "Groups" : "Grups",
    "Links" : "Enllaços",
    "Mails" : "Correus electrònics",
    "Federated sent" : "Federat enviat",
    "Federated received" : "Federat rebut",
    "Talk conversations" : "Converses",
    "24 hours" : "24 hores",
    "1 hour" : "1 hora",
    "5 mins" : "5 minuts",
    "Copy" : "Copia",
    "Copied!" : "S'ha copiat!",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Premeu ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Premeu Ctrl-C per copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorització",
    "Monitoring app with useful server information" : "Aplicació per monitoritzar amb informació útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona informació útil del servidor, com ara la càrrega del processador, l’ús de memòria RAM, l’ús del disc, el nombre d’usuaris, etc.",
    "Operating System" : "Sistema Operatiu",
    "CPU" : "Processador",
    "Memory" : "Memòria",
    "Server time" : "Hora del servidor",
    "Uptime" : "Temps de funcionament",
    "Time Servers" : "Servidors d'hora",
    "Load" : "Càrrega",
    "Disk" : "Disc",
    "Mount" : "Muntatge",
    "Filesystem" : "Sistema de fitxers",
    "Size" : "Mida",
    "Available" : "Disponible",
    "Used" : "Utilitzat",
    "You will get a notification once one of your disks is nearly full." : "Rebreu una notificació quan un dels vostres discs estigui gairebé ple.",
    "Files:" : "FItxers:",
    "Storages:" : "Emmagatzematges:",
    "Free Space:" : "Espai lliure:",
    "Network" : "Xarxa",
    "Hostname" : "Servidor",
    "DNS" : "DNS",
    "Gateway" : "Passarel·la",
    "Status" : "Estat",
    "Speed" : "Velocitat",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuaris actius",
    "Total users:" : "Total d'usuaris:",
    "Shares" : "Compartits",
    "PHP" : "PHP",
    "Version:" : "Versió:",
    "Memory Limit:" : "Límit de la Memòria:",
    "Max Execution Time:" : "Temps màxim de l'execució:",
    "Upload max size:" : "Mida màxima per càrregues:",
    "Database" : "Base de dades",
    "Type:" : "Tipus:",
    "Size:" : "Mida:",
    "External monitoring tool" : "Eina externa de monitorització",
    "You can connect an external monitoring tool by using this end point:" : "Podeu connectar una eina externa de monitorització fent servir aquest punt final:",
    "Did you know?" : "Ho sabíeu?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Afegint \"?format=json\" al final de l’URL us proporciona el resultat en format JSON!",
    "Last 24 hours" : "Darreres 24 hores",
    "Last 1 hour" : "Darrera hora",
    "Last 5 mins" : "Darrers 5 minuts",
    "CPU load" : "Càrrega del processador",
    "Memory usage" : "Ús de memòria",
    "Storage" : "Emmagatzematge",
    "Users:" : "Usuaris:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Aplicacions instal·lades:",
    "Apps updates available:" : "Actualitzacions d’aplicacions disponibles:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/serverinfo/l10n/ca.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informació del processador no disponible",
    "Load average" : "Càrrega mitja",
    "Last minute" : "Darrer minut",
    "Memory info not available" : "Informació de la memòria no disponible",
    "Total" : "Total",
    "Current usage" : "Ús actual",
    "Users" : "Usuaris",
    "Groups" : "Grups",
    "Links" : "Enllaços",
    "Mails" : "Correus electrònics",
    "Federated sent" : "Federat enviat",
    "Federated received" : "Federat rebut",
    "Talk conversations" : "Converses",
    "24 hours" : "24 hores",
    "1 hour" : "1 hora",
    "5 mins" : "5 minuts",
    "Copy" : "Copia",
    "Copied!" : "S'ha copiat!",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Premeu ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Premeu Ctrl-C per copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorització",
    "Monitoring app with useful server information" : "Aplicació per monitoritzar amb informació útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona informació útil del servidor, com ara la càrrega del processador, l’ús de memòria RAM, l’ús del disc, el nombre d’usuaris, etc.",
    "Operating System" : "Sistema Operatiu",
    "CPU" : "Processador",
    "Memory" : "Memòria",
    "Server time" : "Hora del servidor",
    "Uptime" : "Temps de funcionament",
    "Time Servers" : "Servidors d'hora",
    "Load" : "Càrrega",
    "Disk" : "Disc",
    "Mount" : "Muntatge",
    "Filesystem" : "Sistema de fitxers",
    "Size" : "Mida",
    "Available" : "Disponible",
    "Used" : "Utilitzat",
    "You will get a notification once one of your disks is nearly full." : "Rebreu una notificació quan un dels vostres discs estigui gairebé ple.",
    "Files:" : "FItxers:",
    "Storages:" : "Emmagatzematges:",
    "Free Space:" : "Espai lliure:",
    "Network" : "Xarxa",
    "Hostname" : "Servidor",
    "DNS" : "DNS",
    "Gateway" : "Passarel·la",
    "Status" : "Estat",
    "Speed" : "Velocitat",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuaris actius",
    "Total users:" : "Total d'usuaris:",
    "Shares" : "Compartits",
    "PHP" : "PHP",
    "Version:" : "Versió:",
    "Memory Limit:" : "Límit de la Memòria:",
    "Max Execution Time:" : "Temps màxim de l'execució:",
    "Upload max size:" : "Mida màxima per càrregues:",
    "Database" : "Base de dades",
    "Type:" : "Tipus:",
    "Size:" : "Mida:",
    "External monitoring tool" : "Eina externa de monitorització",
    "You can connect an external monitoring tool by using this end point:" : "Podeu connectar una eina externa de monitorització fent servir aquest punt final:",
    "Last 24 hours" : "Darreres 24 hores",
    "Last 1 hour" : "Darrera hora",
    "Last 5 mins" : "Darrers 5 minuts",
    "CPU load" : "Càrrega del processador",
    "Memory usage" : "Ús de memòria",
    "Storage" : "Emmagatzematge",
    "Users:" : "Usuaris:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Aplicacions instal·lades:",
    "Apps updates available:" : "Actualitzacions d’aplicacions disponibles:",
    "Did you know?" : "Ho sabíeu?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Afegint \"?format=json\" al final de l’URL us proporciona el resultat en format JSON!"
},
"nplurals=2; plural=(n != 1);");
